@@ -3,11 +3,11 @@ function()
 {
 	write("        ,.-.,                                                                                   ", file="")
 	write("      .`     `.                                                                                 ", file="")
-	write("     /.-., ,.-.`            *       *                                 ****     ****    *******  ", file="")
-	write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *    *   *        ", file="")
+	write("     /.-., ,.-.`            *       *                                 ****     ****    ******   ", file="")
+	write("   .`    .`.    `.     ***   *     *   ***    ****   ****    *     * *    *   *    *  *         ", file="")
 	write("  / `.  /   `.  / `  *     *  *   *  *     * *    * *    *    *   *      *        *    ******   ", file="")
-	write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *         *          *  ", file="")
-	write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *       *    *         *  ", file="")
+	write(" |    ',_____,'    | ******   *   *  ******  *    * *    *     * *      *         *   *      *  ", file="")
+	write(" `.     `   /     /  *         * *   *       *    * *    *     * *    *       *    *  *      *  ", file="")
 	write("   ',    '_'    ,'    *****     *     *****  *    * *    *      *    ****** *  ****  * ******   ", file="")
 	write("     `'-'` `'-'`                                                                                ", file="")
 	write("\n#####################", file="")
